[0.8.1]
-------------------------------
- Changed required version of Click to >=7.0,<8

[0.8]
-------------------------------
- Add missing files to sdist

[0.7]
-------------------------------
- Add support for NO_COLOR <https://no-color.org/>
- Add support for MultiCommands
- Add support for version_option
